@@ -194,7 +194,7 @@ class Definition:
 		items = []
 		i = 0
 		for entry in value:
-			item = Index.validate_input(None, field_fqn + '[' + str(i) + ']', field_name, self.data_format, entry)
+			item = Index.validate_input(None, field_fqn + '[' + str(i) + ']', field_name, self.data_format, entry, **rules_kw)
 			items.append(item[field_name])
 			i = i + 1
 		results[field_name] = items
@@ -402,6 +402,7 @@ class DefinitionJsonDeserializer:
 		self._set(obj, kw, 'load_defaults')
 		self._set(obj, kw, 'model')
 		self._set(obj, kw, 'dependency_resolver')
+		self._set(obj, kw, 'return_unknown_fields')
 		kw['model_name'] = name
 		model = {}
 		field_init_actions = []
