@@ -8,6 +8,7 @@ class Schema:
 	model = None
 	model_name = None
 	allow_unknown_fields = False
+	return_unknown_fields = False
 	display_name = None
 	case_sensitive = True
 	load_defaults = False
@@ -21,7 +22,8 @@ class Schema:
 				display_name=Utils.Empty,
 				case_sensitive=Utils.Empty,
 				load_defaults=Utils.Empty,
-				dependency_resolver=Utils.Empty
+				dependency_resolver=Utils.Empty,
+				return_unknown_fields=Utils.Empty
 			):
 		def _set_member(name, value):
 			if Utils.Empty.isempty(value):
@@ -38,6 +40,7 @@ class Schema:
 		_set_member('case_sensitive', case_sensitive)
 		_set_member('load_defaults', load_defaults)
 		_set_member('dependency_resolver', dependency_resolver)
+		_set_member('return_unknown_fields', return_unknown_fields)
 		if self.model_name is None:
 			self.model_name = model.__class__.__name__
 
@@ -87,7 +90,6 @@ class Field:
 	required = True
 	ignored = False
 	unvalidated = False
-	dependency_resolver = None
 	default_value = Utils.Empty
 
 	def __init__(
@@ -98,7 +100,6 @@ class Field:
 				required=Utils.Empty,
 				ignored=Utils.Empty,
 				unvalidated=Utils.Empty,
-				dependency_resolver=Utils.Empty,
 				default_value=Utils.Empty
 			):
 		def _set_member(name, value):
@@ -111,7 +112,6 @@ class Field:
 		_set_member('required', required)
 		_set_member('ignored', ignored)
 		_set_member('unvalidated', unvalidated)
-		_set_member('dependency_resolver', dependency_resolver)
 		_set_member('default_value', default_value)
 
 	# Broken
@@ -433,14 +433,14 @@ class ModelValidator:
 				setattr(target, value_name, value)
 		return value
 
-	def _resolve_field_definition(self, fqn, field_name, dependency_values):
+	def _resolve_field_definition(self, fqn, field_name, dependency_values, **kw):
 		definition_name = self.get_field_definition_name(field_name)
 		definition = Definitions.Index.get(definition_name)
 		if definition.is_one_of():
 			if self.schema.dependency_resolver is None:
 				raise Config.exception_factory.create_input_error(fqn, 'Schema field dependency resolver missing.')
 			try:
-				definition_name = self.schema.dependency_resolver.resolve(fqn, field_name, dependency_values)
+				definition_name = self.schema.dependency_resolver.resolve(fqn, field_name, dependency_values, **kw)
 				if definition_name not in definition.get_data_format():
 					msg = "Schema field cannot be '{0}' (must be one of: {1})".format(definition_name, definition.get_data_format())
 					raise Config.exception_factory.create_internal_error(fqn, msg)
@@ -466,10 +466,9 @@ class ModelValidator:
 		# SOLUTION: Overwrite defaults but always return the original
 		#           ref where possible.
 		result = Parameters.Index.ensure(validated)
+		normalized = values
 		if isinstance(values, dict):
 			normalized = Parameters.Index(values)
-		else:
-			normalized = values
 		field_names = self._list_input_field_names(normalized)
 		kw = Parameters.Index()
 		missing = set(self.required)
@@ -486,6 +485,8 @@ class ModelValidator:
 					display_name = self.get_field_input_display_name(field_name)
 					raise Config.exception_factory.create_input_error(Config.definition_name_strategy.get_fqn(fqn, display_name), 'Unknown field.')
 				else:
+					if self.schema.return_unknown_fields is True:
+						result[field_name] = self._get_input_value(fqn, field_name, normalized)
 					continue
 			if field_name not in self.ignored:
 				kw[field_name] = self._get_input_value(fqn, field_name, normalized)
@@ -506,7 +507,7 @@ class ModelValidator:
 				continue
 			# Default Value
 			###############
-			field_definition = self._resolve_field_definition(child_fqn, field_name, result)
+			field_definition = self._resolve_field_definition(child_fqn, field_name, result, **rules_kw)
 			if field_name not in kw:
 				if field_definition.has_default_value() and field_name in self.required:
 					result[field_name] = field_definition.get_default_value(field_name)
